==> haskell-doctest-exitcode-stdio-0.0.0.1-63-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-exitcode-stdio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-exitcode-stdio
version:              0.0.0.1
visibility:           public
id:                   doctest-exitcode-stdio-0.0.0.1-Hnt3upFx6O5EuzRto6Au9n
key:                  doctest-exitcode-stdio-0.0.0.1-Hnt3upFx6O5EuzRto6Au9n
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             https://hub.darcs.net/thielema/doctest-exitcode-stdio/
synopsis:             Run doctest'\''s in a Cabal.Test.exitcode-stdio environment
description:
    Run doctest'\''s in a Cabal.Test.exitcode-stdio environment.
    For use with the @doctest-extract@ utility.
    Normally, you should not need to import a module from this package,
    only generated code will do this.

category:             Testing
abi:                  939cacabfab3584f2f2145e035516c2f
exposed:              True
exposed-modules:      Test.DocTest.Driver
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/doctest-exitcode-stdio-0.0.0.1

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/doctest-exitcode-stdio-0.0.0.1

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/doctest-exitcode-stdio-0.0.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-exitcode-stdio
hs-libraries:         HSdoctest-exitcode-stdio-0.0.0.1-Hnt3upFx6O5EuzRto6Au9n
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    doctest-lib-0.1.1.1-B4NEu7hRxm7ApFh0YX7J4I transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-doctest-exitcode-stdio/html/doctest-exitcode-stdio.haddock

haddock-html:         /usr/share/doc/haskell-doctest-exitcode-stdio/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-exitcode-stdio-0.0.0.1-64-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-exitcode-stdio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-exitcode-stdio
version:              0.0.0.1
visibility:           public
id:                   doctest-exitcode-stdio-0.0.0.1-EYP7fedvWzp3yzeC2QLeWy
key:                  doctest-exitcode-stdio-0.0.0.1-EYP7fedvWzp3yzeC2QLeWy
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             https://hub.darcs.net/thielema/doctest-exitcode-stdio/
synopsis:             Run doctest'\''s in a Cabal.Test.exitcode-stdio environment
description:
    Run doctest'\''s in a Cabal.Test.exitcode-stdio environment.
    For use with the @doctest-extract@ utility.
    Normally, you should not need to import a module from this package,
    only generated code will do this.

category:             Testing
abi:                  84c5121602caf07f438fd29b61657337
exposed:              True
exposed-modules:      Test.DocTest.Driver
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/doctest-exitcode-stdio-0.0.0.1

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/doctest-exitcode-stdio-0.0.0.1

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/doctest-exitcode-stdio-0.0.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-exitcode-stdio
hs-libraries:         HSdoctest-exitcode-stdio-0.0.0.1-EYP7fedvWzp3yzeC2QLeWy
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    doctest-lib-0.1.1.1-B4NEu7hRxm7ApFh0YX7J4I transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-doctest-exitcode-stdio/html/doctest-exitcode-stdio.haddock

haddock-html:         /usr/share/doc/haskell-doctest-exitcode-stdio/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
